# LIUNGFU **`permainan sederhana`**

---

`permainan berjalan di localhost dengan port secara acak`

---

- **`bahasa yang digunakan`**
- `python`
- `brython`
- `html`
- `css`

panggil di terminal ketikan `liungfu`

---

```python

if __name__=='__main__':
    from liungfu import main
    main()

```

---
